@@ -18,10 +18,10 @@
 def factorial( n ):
     """Computes n! for n an integer >= 0.
     Raises an ArithmeticError otherwise."""
-    if type(n) != type(1) or n < 0:
+    if not isinstance(n, type(1)) or n < 0:
         raise ArithmeticError("factorial only defined on natural numbers.")
     f = 1
-    for i in range(1,n+1):
+    for i in range(1, n+1):
         f = f * i
     return f
 
