@@ -15,20 +15,21 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with FIAT. If not, see <http://www.gnu.org/licenses/>.
 
-import morley, reference_element, numpy
+from . import morley, reference_element
+import numpy
 
 # Let's set up the reference triangle and another one
 Khat = reference_element.UFCTriangle()
 
-newverts = ((-1.0,0.0),(42.0,-0.5),(0.0,1.0))
+newverts = ((-1.0, 0.0), (42.0, -0.5), (0.0, 1.0))
 newtop = Khat.get_topology()
 
-K = reference_element.ReferenceElement( reference_element.TRIANGLE , \
+K = reference_element.ReferenceElement( reference_element.TRIANGLE, \
                                             newverts, \
                                             newtop )
 
 # Construct the affine mapping between them
-A,b = reference_element.make_affine_mapping( K.get_vertices() ,
+A, b = reference_element.make_affine_mapping( K.get_vertices(),
                                              Khat.get_vertices() )
 
 # build the Morley element on the two triangles
@@ -36,14 +37,14 @@ Mhat = morley.Morley( Khat )
 M = morley.Morley( K )
 
 # get some points on each triangle
-pts_hat = Khat.make_lattice( 4 , 1 )
-pts = K.make_lattice( 4 , 1 )
+pts_hat = Khat.make_lattice( 4, 1 )
+pts = K.make_lattice( 4, 1 )
 
 # as a sanity check on the affine mapping, make sure
 # pts map to pts_hat
 
 for i in range( len( pts ) ):
-    if not numpy.allclose( pts_hat[i],numpy.dot(A,pts[i]) + b):
+    if not numpy.allclose( pts_hat[i], numpy.dot(A, pts[i]) + b):
         print("barf")
 
 # Tabulate the Morley basis on each triangle
@@ -53,42 +54,42 @@ M_tabulated = M.get_nodal_basis().tabulate_new( pts )
 Ainv = numpy.linalg.inv( A )
 AinvT = numpy.transpose( Ainv )
 
-D = numpy.zeros( (6,9) , "d" )
-E = numpy.zeros( (9,6) , "d" )
+D = numpy.zeros( (6, 9), "d" )
+E = numpy.zeros( (9, 6), "d" )
 
-D[0,0] = 1.0
-D[1,1] = 1.0
-D[2,2] = 1.0
+D[0, 0] = 1.0
+D[1, 1] = 1.0
+D[2, 2] = 1.0
 
 for i in range(3):
     n = K.compute_normal(i)
     t = K.compute_normalized_edge_tangent(i)
     nhat = Khat.compute_normal(i)
-    l = K.volume_of_subcomplex(1,i)
-    nt = numpy.transpose( [ n , t ] )
-    [f,g] = numpy.dot( nhat , numpy.dot( AinvT , nt ) ) / l
-    D[3+i,3+i] = f
-    D[3+i,6+i] = g
+    l = K.volume_of_subcomplex(1, i)
+    nt = numpy.transpose( [ n, t ] )
+    [f, g] = numpy.dot( nhat, numpy.dot( AinvT, nt ) ) / l
+    D[3+i, 3+i] = f
+    D[3+i, 6+i] = g
 
 for d in D.tolist():
     print(d)
 print()
 
 for i in range(3):
-    E[i,i] = 1.0
+    E[i, i] = 1.0
 
 for i in range(3):
-    E[3+i,3+i] = K.volume_of_subcomplex(1,i)
+    E[3+i, 3+i] = K.volume_of_subcomplex(1, i)
 
 for i in range(3):
     evids = K.topology[1][i]
-    elen = K.volume_of_subcomplex( 1 , i )
-    E[6+i,evids[1]] = 1.0
-    E[6+i,evids[0]] = -1.0
+    elen = K.volume_of_subcomplex( 1, i )
+    E[6+i, evids[1]] = 1.0
+    E[6+i, evids[0]] = -1.0
 
 print(E)
 print()
-transform = numpy.dot( D , E )
+transform = numpy.dot( D, E )
 ttrans = numpy.transpose( transform )
 
 for row in ttrans:
@@ -96,7 +97,7 @@ for row in ttrans:
 print()
 
 print("max error")
-print(numpy.max( numpy.abs( numpy.dot( numpy.transpose( transform ) , Mhat_tabulated )  - M_tabulated ) ))
+print(numpy.max( numpy.abs( numpy.dot( numpy.transpose( transform ), Mhat_tabulated )  - M_tabulated ) ))
 
 
 
