@@ -265,7 +265,13 @@ def test_quadrature():
         ("Nedelec 2nd kind H(curl)", 3, 2),
         ("Nedelec 2nd kind H(curl)", 3, 3),
         ("Crouzeix-Raviart", 2, 1),
-        ("Crouzeix-Raviart", 3, 1)
+        ("Crouzeix-Raviart", 3, 1),
+        ("Regge", 2, 0),        
+        ("Regge", 2, 1),
+        ("Regge", 2, 2),
+        ("Regge", 3, 0),        
+        ("Regge", 3, 1),
+        ("Regge", 3, 2)
         )
 
     def create_data(family, dim, degree):
